@@ -15,6 +15,10 @@ class PostgreSQLTable(Table):
     def get_schema(cls):
         return cls._schema
 
+    @classmethod
+    def get_full_table_name(cls):
+        return "{}.{}".format(cls.get_schema(), cls.get_table_name())
+
     @classmethod
     def __create_schema(cls):
         return sql.create_schema().format(name=cls.get_schema())
@@ -101,11 +105,6 @@ class PostgreSQLTable(Table):
             if v.primary_key:
                 return getattr(self, k)
 
-    def set_pk(self, val):
-        for k, v in self.__class__._get_column_fields().items():
-            if v.primary_key:
-                self.__dict__[k] = val
-
     @classmethod
     def get_pk_name(cls):
         for k, v in cls._get_column_fields().items():
